# remirepo spec file for php-pecl-http-message
#
# Copyright (c) 2019-2024 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%if 0%{?scl:1}
%global sub_prefix %{scl_prefix}
%scl_package       php-pecl-http-message
%endif

%global with_zts   0%{!?_without_zts:%{?__ztsphp:1}}
%global pecl_name  http_message
%global with_tests 0%{!?_without_tests:1}
# after 40-psr.ini
%global ini_name   50-%{pecl_name}.ini
#global prever     RC2

Summary:        PSR-7 HTTP Message implementation
Name:           %{?sub_prefix}php-pecl-http-message
Version:        1.0.0
Release:        2%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:        MIT
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{pecl_name}-%{version}%{?prever}.tgz

Patch1:         https://patch-diff.githubusercontent.com/raw/improved-php-library/http-message/pull/7.patch

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel >= 7.2
BuildRequires:  %{?scl_prefix}php-pecl-psr-devel >= 0.6
BuildRequires:  %{?scl_prefix}php-pear

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}
%if "%{php_version}" > "8.0"
Requires:       %{?scl_prefix}php-psr%{?_isa} >= 1.2
%else
Requires:       %{?scl_prefix}php-psr%{?_isa} >= 0.6
%endif

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}
Provides:       %{?scl_prefix}php-pecl-%{pecl_name}          = %{version}-%{release}
Provides:       %{?scl_prefix}php-pecl-%{pecl_name}%{?_isa}  = %{version}-%{release}


%description
PSR-7 compatible HTTP Message implementation as PHP extension.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%package devel
Summary:       %{name} developer files (headers)
Group:         Development/Libraries
Requires:      %{name}%{?_isa} = %{version}-%{release}
Requires:      %{?scl_prefix}php-devel%{?_isa}
Provides:      %{?scl_prefix}php-pecl-%{pecl_name}-devel = %{version}-%{release}
Provides:      %{?scl_prefix}php-pecl-%{pecl_name}-devel%{?_isa} = %{version}-%{release}

%description devel
These are the files needed to compile programs using %{name}.


%prep
%setup -q -c
mv %{pecl_name}-%{version}%{?prever} NTS

# Don't install/register tests
%{?_licensedir:sed -e '/LICENSE/s/role="doc"/role="src"/' -i package.xml}

cd NTS
%patch -P1 -p1 -b .pr7

# Sanity check, really often broken
extver=$(sed -n '/#define PHP_HTTP_MESSAGE_VERSION/{s/.* "//;s/".*$//;p}' php_http_message.h)
if test "x${extver}" != "x%{version}%{?prever}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}%{?prever}.
   exit 1
fi
cd ..

%if %{with_zts}
# Duplicate source tree for NTS / ZTS build
cp -pr NTS ZTS
%endif

# Create configuration file
cat << 'EOF' | tee %{ini_name}
; Enable '%{summary}' extension module
extension=%{pecl_name}
EOF


%build
%{?dtsenable}

cd NTS
%{_bindir}/phpize
%configure \
    --enable-http-message \
    --with-php-config=%{_bindir}/php-config
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%{_bindir}/zts-phpize
%configure \
    --enable-http-message \
    --with-php-config=%{_bindir}/zts-php-config
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

make -C NTS install INSTALL_ROOT=%{buildroot}

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Tests & Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 NTS/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done
for i in $(grep 'role="test"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 NTS/$i %{buildroot}%{pecl_testdir}/%{pecl_name}/$i
done


%check
OPT="-n -d extension=psr"

cd NTS
: Minimal load test for NTS extension
%{__php} $OPT \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

%if %{with_tests}
: Upstream test suite  for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="$OPT -d extension=$PWD/modules/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php -q --show-diff
%endif

%if %{with_zts}
cd ../ZTS
: Minimal load test for ZTS extension
%{__ztsphp} $OPT \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

%if %{with_tests}
: Ignore tests using CGI
rm -r tests/Emitter

: Upstream test suite  for NTS extension
TEST_PHP_EXECUTABLE=%{__ztsphp} \
TEST_PHP_ARGS="$OPT -d extension=$PWD/modules/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__ztsphp} -n run-tests.php -q --show-diff
%endif
%endif


%files
%doc %{pecl_docdir}/%{pecl_name}
%{?_licensedir:%license NTS/LICENSE}

%{pecl_xmldir}/%{name}.xml
%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%files devel
%doc %{pecl_testdir}/%{pecl_name}
%{php_incldir}/ext/%{pecl_name}

%if %{with_zts}
%{php_ztsincldir}/ext/%{pecl_name}
%endif


%changelog
* Thu Aug 22 2024 Remi Collet <remi@remirepo.net> - 1.0.0-2
- cleanup

* Mon Dec 13 2021 Remi Collet <remi@remirepo.net> - 1.0.0-1
- update to 1.0.0
- drop patches merged upstream
- open https://github.com/improved-php-library/http-message/issues/5
  version 1.0.0 missing on pecl
- open https://github.com/improved-php-library/http-message/issues/6
  comptibility with psr 1.2.0
- add patch for ext 1.2.0 from
  https://github.com/improved-php-library/http-message/pull/7

* Wed Sep 30 2020 Remi Collet <remi@remirepo.net> - 0.2.2-4
- rebuild for PHP 8.0.0RC1
- add patch from https://github.com/improved-php-library/http-message/pull/4

* Wed Sep  2 2020 Remi Collet <remi@remirepo.net> - 0.2.2-3
- rebuild for PHP 8.0.0beta3

* Tue Sep  1 2020 Remi Collet <remi@remirepo.net> - 0.2.2-2
- add patch for PHP 8 from
  https://github.com/improved-php-library/http-message/pull/3

* Tue Aug 25 2020 Remi Collet <remi@remirepo.net> - 0.2.2-1
- update to 0.2.2

* Thu Nov  7 2019 Remi Collet <remi@remirepo.net> - 0.2.1-1
- update to 0.2.1

* Thu Sep  5 2019 Remi Collet <remi@remirepo.net> - 0.2.0-1
- update to 0.2.0

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 0.1.1-2
- rebuild for 7.4.0RC1

* Mon Jul 29 2019 Remi Collet <remi@remirepo.net> - 0.1.1-1
- update to 0.1.1

* Tue Jul 23 2019 Remi Collet <remi@remirepo.net> - 0.1.0-12
- rebuild for 7.4.0beta1

* Thu Jul 11 2019 Remi Collet <remi@remirepo.net> - 0.1.0-11
- initial package
